import Utils.IxLoadUtils as IxLoadUtils
import Utils.IxRestUtils as IxRestUtils
import inspect

####TEST CONFIG

kGatewayServer = "127.0.0.1"            #TODO - to be changed by user
kGatewayPort = 8443
kIxLoadVersion = "8.40.115.102"         #TODO - to be changed by user
kChassisList = ['chassisIpOrHostName']  #TODO - to be changed by user
kOS="Windows"                             #TODO - to be changed by user depending on the remote OS Windows/Linux
location=inspect.getfile(inspect.currentframe())


kPortListPerCommunityCommunity =    {
                                        "Traffic1@Network1" : [(1,1,1)],
                                        "Traffic2@Network2" : [(1,1,2)]
                                    }

kStatsToDisplayDict =   {
                            #format: { statSource : [stat name list] }
                            "StatelessPeer": ["Active Streams Transmitting","Total Packets Received","Total Packets Sent"]
                        }

kCommunities = [
    # format: {option1: value1, option2: value2}
    {},  # default community with no options
    {"tcpAccelerationAllowedFlag": True}  # community with tcpAccelerationAllowedFlag set to True
]

kActivities = {
    # format: {communityName: [activityProtocolAndType1, activityProtocolAndType2]}
    'Traffic1@Network1': ['stateless Peer'],
    'Traffic2@Network2': ['stateless Peer']
}

#create a connection to the gateway
connection = IxRestUtils.getConnection(kGatewayServer, kGatewayPort)
sessionUrl = None

try:
    # create a session
    IxLoadUtils.log("Creating a new session...")
    sessionUrl = IxLoadUtils.createSession(connection, kIxLoadVersion)
    IxLoadUtils.log("Session created.")


    # create nettraffics (communities)
    IxLoadUtils.log('Creating communities...')
    IxLoadUtils.addCommunities(connection, sessionUrl, kCommunities)
    IxLoadUtils.log('Communities created.')


    # create activities
    IxLoadUtils.log('Creating activities...')
    IxLoadUtils.addActivities(connection, sessionUrl, kActivities)
    IxLoadUtils.log('Activities created.')

    #Generate IP Stream command
    IxLoadUtils.log('Adding Generate IP Stream command to StatelessPeer2...')
    IxLoadUtils.log('IP in IP encapsulation ...')
    StatelessPeerCommandOptions1 = {'commandType': 'GenerateIPStream', 'remotePeer': 'Traffic2_StatelessPeer1', 'proto':'4','maxPacketFreq': '1000'}
    IxLoadUtils.StatelessPeerUtils.addStatelessPeerCommand(connection, sessionUrl, 'Traffic1@Network1','StatelessPeer2', StatelessPeerCommandOptions1)
    IxLoadUtils.log('Command added to StatelessPeer2 .')

    #Generate UDP Stream command
    IxLoadUtils.log('Adding Generate UDP Stream command to StatelessPeer1...')
    StatelessPeerCommandOptions2 = {'commandType': 'GenerateStream','destination': 'Traffic1_StatelessPeer2','remotePeer': 'Traffic1_StatelessPeer2' }
    IxLoadUtils.StatelessPeerUtils.addStatelessPeerCommand(connection, sessionUrl, 'Traffic2@Network2','StatelessPeer1', StatelessPeerCommandOptions2)
    IxLoadUtils.log('Command added to StatelessPeer1.')


    IxLoadUtils.log("Clearing chassis list...")
    IxLoadUtils.clearChassisList(connection, sessionUrl)
    IxLoadUtils.log("Chassis list cleared.")

    IxLoadUtils.log("Adding chassis %s..." % (kChassisList))
    IxLoadUtils.addChassisList(connection, sessionUrl, kChassisList)
    IxLoadUtils.log("Chassis added.")

    IxLoadUtils.log("Assigning new ports...")
    IxLoadUtils.assignPorts(connection, sessionUrl, kPortListPerCommunityCommunity)
    IxLoadUtils.log("Ports assigned.")

    IxLoadUtils.log("Saving repository %s..." % (IxLoadUtils.getRxfName(kOS,location)))
    IxLoadUtils.saveRxf(connection, sessionUrl, IxLoadUtils.getRxfName(kOS,location))
    IxLoadUtils.log("Repository saved.")

    IxLoadUtils.log("Starting the test...")
    IxLoadUtils.runTest(connection, sessionUrl)
    IxLoadUtils.log("Test started.")

    IxLoadUtils.log("Polling values for stats %s..." % (kStatsToDisplayDict))
    IxLoadUtils.pollStats(connection, sessionUrl, kStatsToDisplayDict)

    IxLoadUtils.log("Test finished.")

    IxLoadUtils.log("Checking test status...")
    testRunError = IxLoadUtils.getTestRunError(connection, sessionUrl)
    if testRunError:
        IxLoadUtils.log("The test exited with the following error: %s" % testRunError)
    else:
        IxLoadUtils.log("The test completed successfully.")

    IxLoadUtils.log("Waiting for test to clean up and reach 'Unconfigured' state...")
    IxLoadUtils.waitForTestToReachUnconfiguredState(connection, sessionUrl)
    IxLoadUtils.log("Test is back in 'Unconfigured' state.")
finally:
    if sessionUrl is not None:
        IxLoadUtils.log("Closing IxLoad session...")
        IxLoadUtils.deleteSession(connection, sessionUrl)
        IxLoadUtils.log("IxLoad session closed.")
