#------------------------------------------------------------------------------
# Name          : enable_disable_credentials.tcl
# Author        : 
# Purpose       : Using Virtual Chassis Builder APIs add discovery credential with -enable flag 0 (disabled).
#				  and 1 (enable).
# Test Steps    : 1. View Chassis Builder Credential & Remove that crededntial.
#				  2. Add discovery credential with -enbale flag 0 (disabled).Check that no VMs are discovered.
#                 3. Add credential with -enbale flag 1 (enable) & Check that VMs are discovered again.
#             
#
# Prerequisite  : A Chassis is already deployed & reachable. One discovery credential is added.
#------------------------------------------------------------------------------

# You defined Deployed Chassis IP & Deployed Card IP this this file 
source common.tcl

#-----------------------------------
# setup path and load IxLoad package
#-----------------------------------
source ../setup_simple.tcl
#Manual
# source "C:/Program Files (x86)/Ixia/IxLoad/8.20.0.206-EB/TclScripts/bin/IxiaWish.tcl"
# package require IxLoad

#-------------------------------------
# Initialize IxLoad
#-------------------------------------

#IxLoad connect should always be called, even for local scripts
# ::IxLoad connect 1.2.3.4

::IxLoad connect $::IxLoadPrivate::SimpleSettings::remoteServer

#--------------------------------------
# setup logger
#--------------------------------------
set logtag "IxLoad-api"
set logName "cbapi_log"
set logger [::IxLoad new ixLogger $logtag 1]
set logEngine [$logger getEngine]
$logEngine setLevels $::ixLogger(kLevelDebug) $::ixLogger(kLevelInfo)
$logEngine setFile $logName 2 256 1

puts "#############################################"
puts "Starting Sample Test : enable_disable_credentials.tcl "
puts "#############################################"

puts ""
puts "-------------------------------------------------------------"
puts "Conneting to the Chassis : $chassisIP (This Is Your Deployed Chassis IP!)"
puts "--------------------------------------------------------------"
set chassisBuilder [::IxLoad new ixChassisBuilder]
$chassisBuilder connectToChassis  -chassisName $chassisIP
puts $chassisBuilder


### Get discovery credentials #########
# Assuming Chassis Builder has ONE discovery Credential already Added.

set credentials [$chassisBuilder getDiscoveredCredentials ]
set count_initial    [$credentials indexCount]
puts "Total Number of Hypervisors: $count_initial"
if {$count_initial > 0} {
set serverInfo     [$credentials getItem 0]

set Enabled        [$serverInfo cget -Enabled]
set ErrorMessage   [$serverInfo cget -ErrorMessage]
set HasError       [$serverInfo cget -HasError]
set ServerName     [$serverInfo cget -ServerName]
set ServerPassword [$serverInfo cget -ServerPassword]
set ServerType     [$serverInfo cget -ServerType]
set ServerUser     [$serverInfo cget -ServerUser]
puts "Enabled         = $Enabled"
puts "Error Message   = $ErrorMessage"
puts "Has Error       = $HasError"
puts "Server name     = $ServerName"
puts "Server Password = $ServerPassword"
puts "Server Type     = $ServerType"
puts "Server User     = $ServerUser"
}

puts ""
puts "---------------------------------------------"
puts "Remove Discovery Credential."
puts "---------------------------------------------"

puts "Removing credentials..."
$chassisBuilder removeCredential -serverName $ServerName

after 1000

set credentials [$chassisBuilder getDiscoveredCredentials ]
set count_delete    [$credentials indexCount]
if {$count_delete != $count_initial -1} {
    error "Delete Credentials operation is not working; Stop test"
}
puts "Rediscovering VMs after credential is removed."
$chassisBuilder rediscoverAppliances
after 3000

puts "Getting discovered machines"
set machines [$chassisBuilder getDiscoveredMachines]
set count    [$machines indexCount]
puts "Total number of hypervisors: $count"
if {$count > 0} {
    error "Delete Credentials operation is not working; Stop test"
} else {
	puts "No VM discovered."
	}
	
puts ""
puts "-----------------------------------------------"
puts "Add Discovery Credential With -enable flag '0' "
puts "-----------------------------------------------"

$chassisBuilder addCredentials -serverName $ServerName -enable 0 -user $ServerUser -password $ServerPassword -applianceType $ServerType

after 1000

set credentials [$chassisBuilder getDiscoveredCredentials ]
set count_add    [$credentials indexCount]
puts "Total number of hypervisors: $count_add"
if {$count_add != 1} {
        error "Add Credentials operation is not working; Stop test"
} else {
	puts "Credential added & disabled."}

set serverInfo     [$credentials getItem 0]

set Enabled_new        [$serverInfo cget -Enabled]
set ErrorMessage   [$serverInfo cget -ErrorMessage]
set HasError       [$serverInfo cget -HasError]
set ServerName     [$serverInfo cget -ServerName]
set ServerPassword [$serverInfo cget -ServerPassword]
set ServerType     [$serverInfo cget -ServerType]
set ServerUser     [$serverInfo cget -ServerUser]
puts "Enabled         = $Enabled_new"
puts "Error Message   = $ErrorMessage"
puts "Has Error       = $HasError"
puts "Server name     = $ServerName"
puts "Server Password = $ServerPassword"
puts "Server Type     = $ServerType"
puts "Server User     = $ServerUser"

puts "Rediscovering to Check if NO VMs will be discovered..."
$chassisBuilder rediscoverAppliances
after 3000

puts "Getting discovered machines"
set machines [$chassisBuilder getDiscoveredMachines]
set count    [$machines indexCount]
puts "Total number of discovered machines: $count"
if {$count > 0} {
    error "Discovery Credentials operation is not working; Stop test"
} else {
	puts "NO VMs Discovered."
	}

puts ""
puts "---------------------------------------------"
puts "Remove this Discovery Credential."
puts "---------------------------------------------"
$chassisBuilder removeCredential -serverName $ServerName

after 1000
set credentials [$chassisBuilder getDiscoveredCredentials ]
set count_delete    [$credentials indexCount]
if {$count_delete > 0 } {
    error "Delete Credentials operation is not working; Stop test"
} else {
	puts "Credential removed."}

puts ""
puts "------------------------------------------------"
puts "Now Add Same Discovery Credential with -enable flag =1"
puts "------------------------------------------------"

$chassisBuilder addCredentials -serverName $ServerName -enable $Enabled -user $ServerUser -password $ServerPassword -applianceType $ServerType

after 1000

set credentials [$chassisBuilder getDiscoveredCredentials ]
set count_add    [$credentials indexCount]
puts "Total Number of Hypervisors: $count_add"
if {$count_add != 1} {
	error "Add Credentials operation is not working; Stop test"
}

set serverInfo     [$credentials getItem 0]

set Enabled        [$serverInfo cget -Enabled]
set ErrorMessage   [$serverInfo cget -ErrorMessage]
set HasError       [$serverInfo cget -HasError]
set ServerName     [$serverInfo cget -ServerName]
set ServerPassword [$serverInfo cget -ServerPassword]
set ServerType     [$serverInfo cget -ServerType]
set ServerUser     [$serverInfo cget -ServerUser]
puts "Enabled         = $Enabled"
puts "Error Message   = $ErrorMessage"
puts "Has Error       = $HasError"
puts "Server name     = $ServerName"
puts "Server Password = $ServerPassword"
puts "Server Type     = $ServerType"
puts "Server User     = $ServerUser"

puts "Rediscovering VMs to check if credential successfully enabled..."
$chassisBuilder rediscoverAppliances
after 3000

puts "Getting discovered machines"
set machines [$chassisBuilder getDiscoveredMachines]
set count    [$machines indexCount]
puts "Total number of discovered machines: $count"
if {$count == 0} {
    error "Add Credentials operation is not working; Stop test"
}
puts ""
    

#################
#   TEST END    #
#################
::IxLoad disconnect
